Package: ppcSpatial
Type: Package
Title: Spatial Analysis of Pakistan Population Census
Version: 0.3.0
Authors@R: c(
              person(c("Muhammad", "Yaseen"),  email = "myaseen208@gmail.com", role = c("aut", "cre"))
            , person(c("Muhammad", "Arfan", "Dilber"),  email = "pbsfsd041@gmail.com", role = c("aut", "ctb"))
            )
Maintainer: Muhammad Yaseen <myaseen208@gmail.com>
Description: Spatial Analysis for exploration of Pakistan Population Census 2017 (<https://www.pbs.gov.pk/content/population-census>). It uses data from R package 'PakPC2017'.
Depends: R (>= 3.1)
Imports: dplyr, ggplot2, htmltools, htmlwidgets, leaflet, magrittr,
        PakPC2017, scales, shiny, tidyr, tmap
Suggests: testthat
License: GPL-3
URL: https://github.com/MYaseen208/ppcSpatial
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-04-29 06:59:41 UTC; hp
Author: Muhammad Yaseen [aut, cre],
  Muhammad Arfan Dilber [aut, ctb]
Repository: CRAN
Date/Publication: 2023-04-29 07:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:16:37 UTC; unix
