library(dplyr)
library(ggplot2)
library(htmltools)
library(htmlwidgets)
library(leaflet)
library(magrittr)
library(PakPC2017)
library(rgdal)
library(scales)
library(shiny)
library(testthat)
library(tidyr)
library(tmap)


source("tableOut.R")
source("plotProvinces.R")
source("plotDivisions.R")
source("plotDistricts.R")
source("plotTehsils.R")
source("plotCity.R")
